@@ -2,14 +2,21 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 from types import ModuleType
+
 import Namcap.ruleclass
 
 # Tarball rules
+# PKGBUILD and metadata rules
 from . import (  # noqa: F401
     anyelf,
+    arrays,
+    badbackups,
+    carch,
+    dbus1location,
     elffiles,
     emptydir,
     externalhooks,
+    extravars,
     fhs,
     filenames,
     fileownership,
@@ -17,41 +24,35 @@ from . import (  # noqa: F401
     hardlinks,
     hookdepends,
     infodirectory,
+    invalidstartdir,
     javafiles,
     libtool,
     licensepkg,
     lotsofdocs,
+    makedepends,
+    makepkgfunctions,
     missingbackups,
+    missingvars,
     pathdepends,
-    perllocal,
     pcdepends,
+    perllocal,
     permissions,
+    pkginfo,
+    pkgnameindesc,
     py_mtime,
     pydepends,
     qmldepends,
     rpath,
     runpath,
     scrollkeeper,
+    sfurl,
     shebangdepends,
     sodepends,
-    symlink,
-    unusedsodepends,
-)
-
-# PKGBUILD and metadata rules
-from . import (  # noqa: F401
-    arrays,
-    badbackups,
-    carch,
-    extravars,
-    invalidstartdir,
-    makedepends,
-    makepkgfunctions,
-    missingvars,
-    pkginfo,
-    pkgnameindesc,
-    sfurl,
+    sphinxbuildcachefiles,
     splitpkgbuild,
+    symlink,
+    systemdlocation,
+    unusedsodepends,
 )
 
 all_rules = {}
@@ -61,5 +62,5 @@ for name, value in dict(locals()).items():
     if name == "Namcap.ruleclass":
         continue
     for n, v in value.__dict__.items():
-        if type(v) == type and issubclass(v, Namcap.ruleclass.AbstractRule) and hasattr(v, "name"):
+        if isinstance(v, type) and issubclass(v, Namcap.ruleclass.AbstractRule) and hasattr(v, "name"):
             all_rules[v.name] = v
