@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 import re
+
 from Namcap.ruleclass import TarballRule
 
 
@@ -27,4 +28,4 @@ class HookDependsRule(TarballRule):
                 continue
             pattern = re.compile(subrule["path"])
             if any(pattern.search(n) for n in names):
-                self.warnings.append(("external-hooks-unneeded %s", dep))
+                self.warnings.append(("external-hooks-unneeded %s", (dep,)))
