@@ -2,8 +2,9 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 import os
-from Namcap.tests.makepkg import MakepkgTest
+
 import Namcap.rules.externalhooks
+from Namcap.tests.makepkg import MakepkgTest
 
 
 class ExternalHooksTest(MakepkgTest):
@@ -15,7 +16,7 @@ pkgdesc="A package"
 arch=('any')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
-depends=('musl')
+depends=('glibc')
 options=(emptydirs)
 install=sample.install
 source=()
@@ -52,7 +53,7 @@ post_install() {
         self.assertEqual(r.errors, [])
         self.assertEqual(
             r.warnings,
-            [("external-hooks %s", "update-desktop-database"), ("external-hooks %s", "gtk-update-icon-cache")],
+            [("external-hooks %s", ("update-desktop-database",)), ("external-hooks %s", ("gtk-update-icon-cache",))],
         )
         self.assertEqual(r.infos, [])
 
