@@ -2,8 +2,9 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 import os
-from Namcap.tests.makepkg import MakepkgTest
+
 import Namcap.rules.hardlinks
+from Namcap.tests.makepkg import MakepkgTest
 
 
 class HardlinksTest(MakepkgTest):
@@ -12,19 +13,19 @@ pkgname=__namcap_test_hardlinks
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64' 'aarch64' 'riscv64' 'loongarch64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
-depends=('musl')
+depends=('glibc')
 source=()
 build() {
   true
 }
 package() {
   mkdir -p "${pkgdir}/usr/bin"
-  mkdir -p "${pkgdir}/usr/sbin-test"
+  mkdir -p "${pkgdir}/usr/sbin"
   touch "${pkgdir}/usr/bin/prog1"
-  ln "${pkgdir}/usr/bin/prog1" "${pkgdir}/usr/sbin-test/prog2"
+  ln "${pkgdir}/usr/bin/prog1" "${pkgdir}/usr/sbin/prog2"
 }
 """
 
@@ -36,6 +37,6 @@ package() {
         self.run_makepkg()
         pkg, r = self.run_rule_on_tarball(os.path.join(self.tmpdir, pkgfile), Namcap.rules.hardlinks.package)
         errors = [(s, set(tup)) for (s, tup) in r.errors]
-        self.assertEqual(errors, [("cross-dir-hardlink %s %s", set(("usr/bin/prog1", "usr/sbin-test/prog2")))])
+        self.assertEqual(errors, [("cross-dir-hardlink %s %s", set(("usr/bin/prog1", "usr/sbin/prog2")))])
         self.assertEqual(r.warnings, [])
         self.assertEqual(r.infos, [])
