@@ -3,15 +3,17 @@
 
 import os
 import tarfile
-import Namcap.rules.licensepkg
 from contextlib import nullcontext as does_not_raise
-from Namcap.tests.makepkg import MakepkgTest
-from Namcap.rules import licensepkg
 from pathlib import Path
-from pytest import mark, raises
-from license_expression import BaseSymbol, LicenseSymbol, LicenseWithExceptionSymbol
 from tarfile import TarInfo
-from typing import ContextManager
+from typing import Any, ContextManager
+
+from license_expression import BaseSymbol, LicenseSymbol, LicenseWithExceptionSymbol
+from pytest import mark, raises
+
+import Namcap.rules.licensepkg
+from Namcap.rules import licensepkg
+from Namcap.tests.makepkg import MakepkgTest
 
 
 @mark.parametrize(
@@ -28,11 +30,26 @@ from typing import ContextManager
         ),
     ],
 )
-def test_get_license_canonicalized(input: str, result: str, expectation: ContextManager) -> None:
+def test_get_license_canonicalized(input: str, result: str, expectation: ContextManager[Any]) -> None:
     with expectation:
         assert result == licensepkg.get_license_canonicalized(input)
 
 
+@mark.parametrize(
+    "input, result",
+    [
+        ("LicenseRef-FOO+", "LicenseRef-FOO+"),
+        ("MIT", "MIT"),
+        ("MIT+", "MIT"),
+        ("Apache-2.0+", "Apache-2.0"),
+        ("GPL-3.0-only+", "GPL-3.0-only+"),
+        ("GPL-3.0-or-later+", "GPL-3.0-or-later+"),
+    ],
+)
+def test_strip_plus_from_license(input: str, result: str) -> None:
+    assert LicenseSymbol(result) == licensepkg.strip_plus_from_license(LicenseSymbol(input))
+
+
 @mark.parametrize(
     "input, result, expectation",
     [
@@ -41,6 +58,7 @@ def test_get_license_canonicalized(input: str, result: str, expectation: Context
         ("LicenseRef-FOO", {LicenseSymbol("LicenseRef-FOO")}, does_not_raise()),
         ("MIT AND MIT", {LicenseSymbol("MIT")}, does_not_raise()),
         ("MIT AND Apache-2.0", {LicenseSymbol("MIT"), LicenseSymbol("Apache-2.0")}, does_not_raise()),
+        ("MIT+ OR Apache-2.0+", {LicenseSymbol("MIT"), LicenseSymbol("Apache-2.0")}, does_not_raise()),
         (
             "Apache-2.0 OR (MIT WITH Bootloader-exception)",
             {
@@ -51,9 +69,18 @@ def test_get_license_canonicalized(input: str, result: str, expectation: Context
             },
             does_not_raise(),
         ),
+        (
+            "Apache-2.0+ WITH Bootloader-exception",
+            {
+                LicenseWithExceptionSymbol(
+                    LicenseSymbol("Apache-2.0"), LicenseSymbol("Bootloader-exception", is_exception=True)
+                ),
+            },
+            does_not_raise(),
+        ),
     ],
 )
-def test_get_license_symbols(input: str, result: set[LicenseSymbol], expectation: ContextManager) -> None:
+def test_get_license_symbols(input: str, result: set[LicenseSymbol], expectation: ContextManager[Any]) -> None:
     with expectation:
         assert result == licensepkg.get_license_symbols(input)
 
@@ -89,6 +116,7 @@ def test_get_uncommon_license_symbols(input: set[BaseSymbol], result: set[BaseSy
     [
         ({LicenseSymbol("GPL-3.0-or-later")}, set()),
         ({LicenseSymbol("LicenseRef-FOO")}, {LicenseSymbol("LicenseRef-FOO")}),
+        ({LicenseSymbol("GPL-3.0-only+")}, {LicenseSymbol("GPL-3.0-only+")}),
         (
             {
                 LicenseWithExceptionSymbol(
@@ -197,7 +225,7 @@ def test_package_license_files(
         ("foo", "../bar", None, raises(ValueError)),
     ],
 )
-def test_get_symlink_target(name: str, linkname: str, result: str, expectation: ContextManager) -> None:
+def test_get_symlink_target(name: str, linkname: str, result: str, expectation: ContextManager[Any]) -> None:
     tarinfo = TarInfo(name)
     tarinfo.linkname = linkname
 
