@@ -1,8 +1,8 @@
 # Copyright (C) 2003-2023 Namcap contributors, see AUTHORS for details.
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from Namcap.tests.pkgbuild_test import PkgbuildTest
 import Namcap.rules.arrays
+from Namcap.tests.pkgbuild_test import PkgbuildTest
 
 
 class NamcapArraysTest(PkgbuildTest):
@@ -14,10 +14,10 @@ pkgname=mypackage
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64' 'aarch64' 'riscv64' 'loongarch64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 url="http://www.example.com/"
 license='GPL-3.0-or-later'
-depends='musl'
+depends='glibc'
 options=('!libtool')
 source=(ftp://ftp.example.com/pub/mypackage-0.1.tar.gz)
 md5sums=('abcdefabcdef12345678901234567890')
@@ -43,5 +43,5 @@ package() {
         "Variables in PKGBUILD are not an array"
         r = self.run_on_pkg(self.pkgbuild1)
         self.assertEqual(r.errors, [])
-        self.assertEqual(set(r.warnings), set(("variable-not-array %s", i) for i in ["depends", "license"]))
+        self.assertEqual(set(r.warnings), set(("variable-not-array %s", (i,)) for i in ["depends", "license"]))
         self.assertEqual(r.infos, [])
