@@ -1,8 +1,8 @@
 # Copyright (C) 2003-2023 Namcap contributors, see AUTHORS for details.
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from Namcap.tests.pkgbuild_test import PkgbuildTest
 import Namcap.rules.invalidstartdir as module
+from Namcap.tests.pkgbuild_test import PkgbuildTest
 
 
 class NamcapInvalidStartdirTest(PkgbuildTest):
@@ -14,7 +14,7 @@ pkgname=mypackage
 pkgver=1.0
 pkgrel=1
 pkgdesc="This program does foobar"
-arch=('i686' 'x86_64' 'riscv64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
 depends=('glibc')
