@@ -14,7 +14,7 @@ pkgname=mypackage
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64')
+
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
 depends=('glibc')
@@ -38,7 +38,7 @@ pkgname=mypackage
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
 depends=('glibc')
@@ -65,7 +65,7 @@ pkgname=mypackage
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
 depends=('glibc' 'pacman')
@@ -92,7 +92,7 @@ pkgver=24.0.1312.5
 pkgrel=1
 pkgdesc="PDF Viewer for Chromium"
 url="http://wiki.archlinux.org/index.php/Chromium#libpdf.so"
-arch=("i686" "x86_64")
+arch=("i686" "x86_64" "riscv64")
 license=('custom:chrome')
 makedepends=('lynx')
 depends=('chromium')
@@ -102,6 +102,9 @@ if [ "$CARCH" = "i686" ]; then
 elif [ "$CARCH" = "x86_64" ]; then
 	_arch="amd64"
 	sha512sums=('1989976e6ca93099c92957e44948d7b73a6f9594304b9fe5313ff44c28c5261852919f2b5dacb49724c77d98667cc3991f8aaef9d3d9b2277eb375293c4a0395')
+elif [ "$CARCH" = "riscv64" ]; then
+	_arch="riscv64"
+	sha512sums=('abcdefabcdefabcdefabcdefabcdefabcdefabcdefabcdef12345678901234567890123456789012345678901234567890123456789012345678901234567890')
 fi
 source=(https://dl.google.com/linux/direct/google-chrome-unstable_current_$_arch.deb)
 
@@ -167,7 +170,7 @@ pkgname=mypackage
 pkgver=1.0
 pkgrel=1
 pkgdesc="The foobar program"
-arch=('i686' 'x86_64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
 depends=('glibc')
@@ -210,7 +213,7 @@ pkgbase=base
 pkgname=(foo bar)
 pkgver=1.0
 pkgrel=1
-arch=('i686' 'x86_64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 depends=('glibc')
 license=('GPL-3.0-or-later')
 url="https://archlinux.org"
@@ -245,7 +248,7 @@ package_bar() {
 pkgname=foo
 pkgver=1.0
 pkgrel=1
-arch=('i686' 'x86_64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 depends=('glibc')
 license=('GPL-3.0-or-later')
 url="https://archlinux.org"
@@ -272,7 +275,7 @@ package() {
 pkgname=foo
 pkgver=1.0
 pkgrel=1
-arch=('i686' 'x86_64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 depends=('glibc')
 pkgdesc='this is the package foo'
 license=('GPL-3.0-or-later')
