@@ -1,8 +1,8 @@
 # Copyright (C) 2003-2023 Namcap contributors, see AUTHORS for details.
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from Namcap.tests.pkgbuild_test import PkgbuildTest
 import Namcap.rules.sfurl as module
+from Namcap.tests.pkgbuild_test import PkgbuildTest
 
 
 class NamcapSourceForgeUrlTest(PkgbuildTest):
@@ -15,8 +15,8 @@ pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
 url="http://mypackage.sf.net/"
-arch=('i686' 'x86_64' 'aarch64' 'riscv64' 'loongarch64')
-depends=('musl')
+arch=('i686' 'x86_64')
+depends=('glibc')
 license=('GPL-3.0-or-later')
 options=('!libtool')
 source=(ftp://heanet.dl.sourceforge.net/pub/m/mypackage/mypackage-0.1.tar.gz)
