@@ -16,7 +16,7 @@ pkgname=mypackage
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64')
+arch=('i686' 'x86_64' 'aarch64' 'loong64' 'riscv64')
 url="http://www.example.com/"
 license=('GPL-3.0-or-later')
 depends=('glibc' 'foobar')
